pub struct SelectionState<Id: SelectableId> {
pub selected: Option<Id>,
pub hovered: Option<Id>,
pub bar_idx: Option<usize>,
/* private fields */
}Expand description
Generic selection state for chart elements, parameterized by an ID type.
Tracks which element is selected, which is hovered, and the bar index where the selection occurred. Used by both series and indicator selection.
Fields
selected: Option<Id>Currently selected element
hovered: Option<Id>Currently hovered element (desktop only)
bar_idx: Option<usize>Additional selection metadata (bar index, etc.)
Implementations
Sourceimpl<Id: SelectableId> SelectionState<Id>
impl<Id: SelectableId> SelectionState<Id>
Sourcepub fn set_hovered(&mut self, id: Option<Id>)
pub fn set_hovered(&mut self, id: Option<Id>)
Set hovered element.
Sourcepub fn is_selected(&self, id: Id) -> bool
pub fn is_selected(&self, id: Id) -> bool
Check if a specific element is selected.
Sourcepub fn is_hovered(&self, id: Id) -> bool
pub fn is_hovered(&self, id: Id) -> bool
Check if a specific element is hovered.
Sourcepub fn has_selection(&self) -> bool
pub fn has_selection(&self) -> bool
Check if any element is selected.
Sourcepub fn selected_id(&self) -> Option<Id>
pub fn selected_id(&self) -> Option<Id>
Get the currently selected element ID.
Sourcepub fn selected_bar(&self) -> Option<usize>
pub fn selected_bar(&self) -> Option<usize>
Get the bar index where selection occurred.